@@ -66,214 +66,122 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_ceb extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String metaValue_ja = "Hinapon";
         final String metaValue_ko = "Korean";
         final Object[][] data = new Object[][] {
-            { "PR", "Puerto Rico" },
-            { "PS", "Palestinian Territories" },
-            { "PT", "Portugal" },
-            { "pt", "Portuguese" },
-            { "PW", "Palau" },
-            { "PY", "Paraguay" },
-            { "pt_BR", "Brazilyanong Portuguese" },
-            { "QA", "Qatar" },
-            { "es_ES", "Espanyol sa Europe" },
-            { "QO", "Outlying Oceania" },
+            { "001", "kalibutan" },
+            { "002", "Africa" },
+            { "003", "North America" },
+            { "005", "South America" },
+            { "009", "Oceania" },
+            { "011", "Western Africa" },
+            { "013", "Central America" },
+            { "014", "Eastern Africa" },
+            { "015", "Northern Africa" },
+            { "017", "Middle Africa" },
+            { "018", "Southern Africa" },
+            { "019", "Americas" },
+            { "021", "Northern America" },
+            { "029", "Caribbean" },
+            { "030", "Eastern Asia" },
+            { "034", "Southern Asia" },
+            { "035", "Southeast Asia" },
+            { "039", "Southern Europe" },
+            { "053", "Australasia" },
+            { "054", "Melanesia" },
+            { "057", "Micronesian Region" },
+            { "061", "Polynesia" },
+            { "142", "Asia" },
+            { "143", "Central Asia" },
+            { "145", "Western Asia" },
+            { "150", "Europe" },
+            { "151", "Eastern Europe" },
+            { "154", "Northern Europe" },
+            { "155", "Western Europe" },
+            { "202", "Sub-Saharan Africa" },
+            { "419", "Latin America" },
             { "AC", "Ascension Island" },
             { "AD", "Andorra" },
             { "AE", "United Arab Emirates" },
-            { "nl_BE", "Flemish" },
             { "AF", "Afghanistan" },
             { "AG", "Antigua & Barbuda" },
             { "AI", "Anguilla" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
-            { "Arab", "Arabo" },
             { "AO", "Angola" },
-            { "Jpan", metaValue_ja },
             { "AQ", "Antarctica" },
-            { "001", "kalibutan" },
             { "AR", "Argentina" },
-            { "ar", "Arabic" },
-            { "002", "Africa" },
             { "AS", "American Samoa" },
-            { "003", "Amihanang Amerika" },
             { "AT", "Austria" },
-            { "RE", "Reunion" },
             { "AU", "Australia" },
-            { "005", "South America" },
             { "AW", "Aruba" },
-            { "en_US", "Ingles sa Amerika" },
             { "AX", "Aland Islands" },
-            { "009", "Oceania" },
             { "AZ", "Azerbaijan" },
-            { "RO", "Romania" },
             { "BA", "Bosnia & Herzegovina" },
             { "BB", "Barbados" },
-            { "RS", "Serbia" },
-            { "ceb", "Binisaya" },
             { "BD", "Bangladesh" },
             { "BE", "Belgium" },
-            { "RU", "Russia" },
-            { "ru", "Ruso" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgaria" },
-            { "RW", "Rwanda" },
             { "BH", "Bahrain" },
             { "BI", "Burundi" },
             { "BJ", "Benin" },
-            { "en_AU", "Ingles sa Australia" },
             { "BL", "St. Barthelemy" },
             { "BM", "Bermuda" },
             { "BN", "Brunei" },
-            { "bn", "Bangla" },
             { "BO", "Bolivia" },
-            { "SA", "Saudi Arabia" },
             { "BQ", "Caribbean Netherlands" },
-            { "SB", "Solomon Islands" },
-            { "011", "Western Africa" },
             { "BR", "Brazil" },
-            { "SC", "Seychelles" },
             { "BS", "Bahamas" },
-            { "SD", "Sudan" },
-            { "013", "Central America" },
             { "BT", "Bhutan" },
-            { "SE", "Sweden" },
-            { "014", "Eastern Africa" },
-            { "015", "Northern Africa" },
             { "BV", "Bouvet Island" },
-            { "SG", "Singapore" },
             { "BW", "Botswana" },
-            { "SH", "St. Helena" },
-            { "017", "Middle Africa" },
-            { "SI", "Slovenia" },
-            { "018", "Southern Africa" },
             { "BY", "Belarus" },
-            { "SJ", "Svalbard & Jan Mayen" },
-            { "019", "Mga Amerika" },
             { "BZ", "Belize" },
-            { "SK", "Slovakia" },
-            { "SL", "Sierra Leone" },
-            { "SM", "San Marino" },
-            { "SN", "Senegal" },
-            { "SO", "Somalia" },
             { "CA", "Canada" },
-            { "SR", "Suriname" },
             { "CC", "Cocos (Keeling) Islands" },
-            { "SS", "South Sudan" },
             { "CD", "Congo - Kinshasa" },
-            { "ST", "Sao Tome & Principe" },
             { "CF", "Central African Republic" },
-            { "SV", "El Salvador" },
             { "CG", "Congo - Brazzaville" },
             { "CH", "Switzerland" },
-            { "SX", "Sint Maarten" },
             { "CI", "Cote d\u2019Ivoire" },
-            { "SY", "Syria" },
-            { "SZ", "Eswatini" },
             { "CK", "Cook Islands" },
             { "CL", "Chile" },
             { "CM", "Cameroon" },
-            { "CN", "Tsina" },
+            { "CN", "China" },
             { "CO", "Colombia" },
             { "CP", "Clipperton Island" },
-            { "TA", "Tristan da Cunha" },
-            { "021", "Northern America" },
-            { "142", "Asya" },
             { "CR", "Costa Rica" },
-            { "TC", "Turks & Caicos Islands" },
-            { "143", "Central Asia" },
-            { "TD", "Chad" },
-            { "145", "Western Asia" },
             { "CU", "Cuba" },
-            { "TF", "French Southern Territories" },
             { "CV", "Cape Verde" },
-            { "TG", "Togo" },
             { "CW", "Curacao" },
-            { "TH", "Thailand" },
-            { "th", "Thai" },
             { "CX", "Christmas Island" },
             { "CY", "Cyprus" },
-            { "TJ", "Tajikistan" },
-            { "en_CA", "Ingles sa Canada" },
-            { "029", "Caribbean" },
             { "CZ", "Czechia" },
-            { "TK", "Tokelau" },
-            { "TL", "Timor-Leste" },
-            { "TM", "Turkmenistan" },
-            { "TN", "Tunisia" },
-            { "TO", "Tonga" },
-            { "TR", "Turkey" },
-            { "tr", "Turkish" },
-            { "pt_PT", "Portuguese sa Europe" },
-            { "TT", "Trinidad & Tobago" },
-            { "DE", "Alemanya" },
-            { "de", "Aleman" },
-            { "TV", "Tuvalu" },
+            { "DE", "Germany" },
             { "DG", "Diego Garcia" },
-            { "TW", "Taiwan" },
             { "DJ", "Djibouti" },
-            { "TZ", "Tanzania" },
             { "DK", "Denmark" },
             { "DM", "Dominica" },
-            { "Zzzz", "Wala Mailhing Script" },
             { "DO", "Dominican Republic" },
-            { "150", "Europe" },
-            { "UA", "Ukraine" },
-            { "030", "Eastern Asia" },
-            { "151", "Eastern Europe" },
-            { "154", "Northern Europe" },
-            { "034", "Southern Asia" },
-            { "155", "Western Europe" },
-            { "035", "Southeast Asia" },
-            { "UG", "Uganda" },
-            { "es_419", "Espanyol sa Latin Amerika" },
-            { "Kore", metaValue_ko },
-            { "039", "Southern Europe" },
             { "DZ", "Algeria" },
-            { "UM", "U.S. Outlying Islands" },
-            { "UN", "Hiniusang Kanasoran" },
             { "EA", "Ceuta & Melilla" },
             { "EC", "Ecuador" },
-            { "US", "Estados Unidos" },
             { "EE", "Estonia" },
             { "EG", "Egypt" },
             { "EH", "Western Sahara" },
-            { "UY", "Uruguay" },
-            { "UZ", "Uzbekistan" },
-            { "en", "Ingles" },
-            { "VA", "Vatican City" },
             { "ER", "Eritrea" },
-            { "VC", "St. Vincent & Grenadines" },
             { "ES", "Espanya" },
-            { "es", "Espanyol" },
             { "ET", "Ethiopia" },
-            { "VE", "Venezuela" },
             { "EU", "European Union" },
-            { "type.ca.gregorian", "Gregorian nga Kalendaryo" },
-            { "VG", "British Virgin Islands" },
-            { "VI", "U.S. Virgin Islands" },
             { "EZ", "Eurozone" },
-            { "VN", "Vietnam" },
-            { "Hans", "Pinasimple" },
-            { "type.nu.latn", "Mga Western Digit" },
-            { "Hant", "Tradisyonal" },
-            { "VU", "Vanuatu" },
             { "FI", "Finland" },
             { "FJ", "Fiji" },
             { "FK", "Falkland Islands" },
             { "FM", "Micronesia" },
             { "FO", "Faroe Islands" },
-            { "FR", "Pransya" },
-            { "fr", "Pranses" },
-            { "053", "Australasia" },
-            { "054", "Melanesia" },
-            { "WF", "Wallis & Futuna" },
-            { "057", "Micronesian Region" },
+            { "FR", "France" },
             { "GA", "Gabon" },
             { "GB", "United Kingdom" },
-            { "ar_001", "Modernong Tamdanang Arabic" },
-            { "WS", "Samoa" },
             { "GD", "Grenada" },
             { "GE", "Georgia" },
             { "GF", "French Guiana" },
@@ -284,79 +192,50 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "GM", "Gambia" },
             { "GN", "Guinea" },
             { "GP", "Guadeloupe" },
-            { "XA", "Pseudo-Accents" },
             { "GQ", "Equatorial Guinea" },
-            { "XB", "Pseudo-Bidi" },
-            { "und", "Wala Mailhing Lengguwahe" },
-            { "061", "Polynesia" },
             { "GR", "Greece" },
-            { "Latn", "Latin" },
             { "GS", "South Georgia & South Sandwich Islands" },
             { "GT", "Guatemala" },
             { "GU", "Guam" },
             { "GW", "Guinea-Bissau" },
             { "GY", "Guyana" },
-            { "XK", "Kosovo" },
-            { "Zxxx", "Dili Sinulat" },
-            { "hi", "Hindi" },
-            { "de_AT", "Austriano nga Aleman" },
             { "HK", "Hong Kong SAR China" },
             { "HM", "Heard & McDonald Islands" },
             { "HN", "Honduras" },
             { "HR", "Croatia" },
             { "HT", "Haiti" },
-            { "YE", "Yemen" },
             { "HU", "Hungary" },
-            { "type.co.standard", "Tamdanang Paagi sa Paghan-ay" },
-            { "es_MX", "Espanyol sa Mexico" },
             { "IC", "Canary Islands" },
             { "ID", "Indonesia" },
-            { "YT", "Mayotte" },
-            { "id", "Indonesian" },
             { "IE", "Ireland" },
             { "IL", "Israel" },
             { "IM", "Isle of Man" },
             { "IN", "India" },
             { "IO", "British Indian Ocean Territory" },
-            { "ZA", "South Africa" },
             { "IQ", "Iraq" },
             { "IR", "Iran" },
             { "IS", "Iceland" },
             { "IT", "Italya" },
-            { "it", "Italiano" },
-            { "zh", "Inintsik" },
-            { "ZM", "Zambia" },
-            { "ja", metaValue_ja },
             { "JE", "Jersey" },
-            { "ZW", "Zimbabwe" },
-            { "ZZ", "Wala Mailhing Rehiyon" },
             { "JM", "Jamaica" },
             { "JO", "Jordan" },
             { "JP", "Japan" },
-            { "type.ca.iso8601", "Kalendaryo sa ISO-8601" },
-            { "de_CH", "Taas nga Aleman sa Switzerland" },
             { "KE", "Kenya" },
-            { "419", "Latin America" },
             { "KG", "Kyrgyzstan" },
             { "KH", "Cambodia" },
             { "KI", "Kiribati" },
             { "KM", "Comoros" },
             { "KN", "St. Kitts & Nevis" },
-            { "fr_CA", "Pranses sa Canada" },
-            { "ko", metaValue_ko },
             { "KP", "North Korea" },
             { "KR", "South Korea" },
-            { "fr_CH", "Pranses sa Switzerland" },
             { "KW", "Kuwait" },
             { "KY", "Cayman Islands" },
             { "KZ", "Kazakhstan" },
-            { "Cyrl", "Sirilisko" },
             { "LA", "Laos" },
             { "LB", "Lebanon" },
             { "LC", "St. Lucia" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
-            { "zh_Hans", "Pinasimpleng Inintsik" },
             { "LR", "Liberia" },
             { "LS", "Lesotho" },
             { "LT", "Lithuania" },
@@ -370,7 +249,6 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "MF", "St. Martin" },
             { "MG", "Madagascar" },
             { "MH", "Marshall Islands" },
-            { "zh_Hant", "Tradisyonal nga Ininstsik" },
             { "MK", "North Macedonia" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
@@ -388,14 +266,12 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "MY", "Malaysia" },
             { "MZ", "Mozambique" },
             { "NA", "Namibia" },
-            { "202", "Sub-Saharan Africa" },
             { "NC", "New Caledonia" },
             { "NE", "Niger" },
             { "NF", "Norfolk Island" },
             { "NG", "Nigeria" },
             { "NI", "Nicaragua" },
             { "NL", "Netherlands" },
-            { "nl", "Dutch" },
             { "NO", "Norway" },
             { "NP", "Nepal" },
             { "NR", "Nauru" },
@@ -403,16 +279,139 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "NZ", "New Zealand" },
             { "OM", "Oman" },
             { "PA", "Panama" },
-            { "en_GB", "Britanikong Ingles" },
             { "PE", "Peru" },
             { "PF", "French Polynesia" },
             { "PG", "Papua New Guinea" },
             { "PH", "Pilipinas" },
             { "PK", "Pakistan" },
             { "PL", "Poland" },
-            { "pl", "Polish" },
             { "PM", "St. Pierre & Miquelon" },
             { "PN", "Pitcairn Islands" },
+            { "PR", "Puerto Rico" },
+            { "PS", "Palestinian Territories" },
+            { "PT", "Portugal" },
+            { "PW", "Palau" },
+            { "PY", "Paraguay" },
+            { "QA", "Qatar" },
+            { "QO", "Outlying Oceania" },
+            { "RE", "Reunion" },
+            { "RO", "Romania" },
+            { "RS", "Serbia" },
+            { "RU", "Russia" },
+            { "RW", "Rwanda" },
+            { "SA", "Saudi Arabia" },
+            { "SB", "Solomon Islands" },
+            { "SC", "Seychelles" },
+            { "SD", "Sudan" },
+            { "SE", "Sweden" },
+            { "SG", "Singapore" },
+            { "SH", "St. Helena" },
+            { "SI", "Slovenia" },
+            { "SJ", "Svalbard & Jan Mayen" },
+            { "SK", "Slovakia" },
+            { "SL", "Sierra Leone" },
+            { "SM", "San Marino" },
+            { "SN", "Senegal" },
+            { "SO", "Somalia" },
+            { "SR", "Suriname" },
+            { "SS", "South Sudan" },
+            { "ST", "Sao Tome & Principe" },
+            { "SV", "El Salvador" },
+            { "SX", "Sint Maarten" },
+            { "SY", "Syria" },
+            { "SZ", "Eswatini" },
+            { "TA", "Tristan da Cunha" },
+            { "TC", "Turks & Caicos Islands" },
+            { "TD", "Chad" },
+            { "TF", "French Southern Territories" },
+            { "TG", "Togo" },
+            { "TH", "Thailand" },
+            { "TJ", "Tajikistan" },
+            { "TK", "Tokelau" },
+            { "TL", "Timor-Leste" },
+            { "TM", "Turkmenistan" },
+            { "TN", "Tunisia" },
+            { "TO", "Tonga" },
+            { "TR", "Turkey" },
+            { "TT", "Trinidad & Tobago" },
+            { "TV", "Tuvalu" },
+            { "TW", "Taiwan" },
+            { "TZ", "Tanzania" },
+            { "UA", "Ukraine" },
+            { "UG", "Uganda" },
+            { "UM", "U.S. Outlying Islands" },
+            { "UN", "Hiniusang Kanasoran" },
+            { "US", "Estados Unidos" },
+            { "UY", "Uruguay" },
+            { "UZ", "Uzbekistan" },
+            { "VA", "Vatican City" },
+            { "VC", "St. Vincent & Grenadines" },
+            { "VE", "Venezuela" },
+            { "VG", "British Virgin Islands" },
+            { "VI", "U.S. Virgin Islands" },
+            { "VN", "Vietnam" },
+            { "VU", "Vanuatu" },
+            { "WF", "Wallis & Futuna" },
+            { "WS", "Samoa" },
+            { "XA", "Pseudo-Accents" },
+            { "XB", "Pseudo-Bidi" },
+            { "XK", "Kosovo" },
+            { "YE", "Yemen" },
+            { "YT", "Mayotte" },
+            { "ZA", "South Africa" },
+            { "ZM", "Zambia" },
+            { "ZW", "Zimbabwe" },
+            { "ZZ", "Wala Mailhing Rehiyon" },
+            { "ar", "Arabic" },
+            { "bn", "Bangla" },
+            { "de", "German" },
+            { "en", "English" },
+            { "es", "Espanyol" },
+            { "fr", "Pranses" },
+            { "hi", "Hindi" },
+            { "id", "Indonesian" },
+            { "it", "Italiano" },
+            { "ja", "Hinapon" },
+            { "ko", metaValue_ko },
+            { "nl", "Dutch" },
+            { "pl", "Polish" },
+            { "pt", "Portuguese" },
+            { "ru", "Russian" },
+            { "th", "Thai" },
+            { "tr", "Turkish" },
+            { "zh", "Inintsik" },
+            { "ceb", "Cebuano" },
+            { "und", "Wala Mailhing Lengguwahe" },
+            { "Arab", "Arabo" },
+            { "Cyrl", "Sirilisko" },
+            { "Hans", "Pinasimple" },
+            { "Hant", "Tradisyonal" },
+            { "Jpan", "Japanese" },
+            { "Kore", metaValue_ko },
+            { "Latn", "Latin" },
+            { "Zxxx", "Dili Sinulat" },
+            { "Zzzz", "Wala Mailhing Script" },
+            { "de_AT", "Austrian German" },
+            { "de_CH", "Swiss High German" },
+            { "en_AU", "English sa Australia" },
+            { "en_CA", "English sa Canada" },
+            { "en_GB", "Britanikong English" },
+            { "en_US", "English sa America" },
+            { "es_ES", "Espanyol sa Europe" },
+            { "es_MX", "Espanyol sa Mexico" },
+            { "fr_CA", "Pranses sa Canada" },
+            { "fr_CH", "Pranses sa Switzerland" },
+            { "nl_BE", "Flemish" },
+            { "pt_BR", "Brazilyanong Portuguese" },
+            { "pt_PT", "Portuguese sa Europe" },
+            { "ar_001", "Modernong Tamdanang Arabic" },
+            { "es_419", "Espanyol sa Latin Amerika" },
+            { "zh_Hans", "Simplified Chinese" },
+            { "zh_Hant", "Traditional nga Chinese" },
+            { "type.nu.latn", "Mga Western Digit" },
+            { "type.ca.iso8601", "Kalendaryo sa ISO-8601" },
+            { "type.co.standard", "Tamdanang Paagi sa Paghan-ay" },
+            { "type.ca.gregorian", "Gregorian nga Kalendaryo" },
         };
         return data;
     }
